summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/spack/spack/package.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/lib/spack/spack/package.py b/lib/spack/spack/package.py
index ff8c8e96bc..8c1204402a 100644
--- a/lib/spack/spack/package.py
+++ b/lib/spack/spack/package.py
@@ -143,8 +143,10 @@ class Package(object):
informational URL, so that users know what they're
installing.
- url
- URL of the source archive that spack will fetch.
+ url or url_for_version(self, version)
+ If url, then the URL of the source archive that spack will fetch.
+ If url_for_version(), then a method returning the URL required
+ to fetch a particular version.
install()
This function tells spack how to build and install the